#!/bin/bash

#     Copyright (C) 2009 Michael Verret <michael.verret@gmail.com>
#
#            This script is released under the terms of the:
#                      GNU GENERAL PUBLIC LICENSE
#                        Version 3, 29 June 2007
#                http://www.gnu.org/licenses/gpl-3.0.txt
#
# This is a Bash shell script written to automate the process of
# generating software packages suitable for use with Zenwalk Linux.
#
# Zenwalk Linux is a GNU/Linux operating system.
#
#              For more information on Zenwalk Linux visit:
#                        http://www.zenwalk.org/
#
# Bash is a free software Unix shell written for the GNU Project.
#
#                   For more information on Bash visit:
#           http://tiswww.case.edu/php/chet/bash/bashtop.html


# Package variables:
#_______________________________________________________________________
Summary="The X C Binding (XCB) library"
Package_Name="xcb"
Package_Version="1.2"
Package_Arch="i686"
Package_Release="62"
Package_Build="6"
File_Package=" \
	xcb-lib-1.2-i686-62.4.tgz \
	xcb-proto-1.4-noarch-62.1.tgz \
	xcb-util-0.3.4-i686-62.1.tgz \
	xpyb-1.1-i686-62.1.tgz"
File_Image=" "
File_Misc=" \
	gpl-3.0.txt.gz"
File_Patch=" "
File_Script=" \
	build-${Package_Name}.sh"
Special_Docs=" "
Desc_Line_00=": (${Summary})"
Desc_Line_01=":"
Desc_Line_02=": The X protocol C-language Binding (XCB) is a replacement"
Desc_Line_03=": for Xlib featuring a small footprint, latency hiding,"
Desc_Line_04=": direct access to the protocol, improved threading support,"
Desc_Line_05=": and extensibility."
Desc_Line_06=":"
Desc_Line_07=":"
Desc_Line_08=":"
Desc_Line_09=":"
Desc_Line_10=":"
# BuildRequires: 
# Requires:


# Constant variables:
#_______________________________________________________________________
Build_Root=$(pwd)
Package_Duo="${Package_Name}-${Package_Version}"
Package_Title="${Package_Duo}-${Package_Arch}-${Package_Release}.${Package_Build}"
Package_Root="${Build_Root}/${Package_Title}"


# Build & install:
#_______________________________________________________________________
for Each in ${File_Package} ; do
	if [ -e ${Each} ] ; then
		echo "${Each} is here, life is good!"
	else
		echo "${Each} is missing, this is really bad!"
		exit 1
	fi
done
if [ -d ${Package_Name}-${Package_Version}-${Package_Arch} ] ; then
	rm -rf ${Package_Name}-${Package_Version}-${Package_Arch}
fi
for Each in ${Package_Title}.dep ${Package_Title}.md5 ${Package_Title}.src.md5 \
	${Package_Title}.src.tbz ${Package_Title}.tgz ; do
	if [ -e ${Each} ] ; then
		rm -rf ${Each}
	fi
done

mkdir -p ${Package_Root}/usr/doc/${Package_Duo}/
zcat ${Build_Root}/gpl-3.0.txt.gz > ${Package_Root}/usr/doc/${Package_Duo}/COPYING

mkdir -p ${Package_Root}/install
mkdir -p ${Package_Root}/usr/src/${Package_Duo}

for Each in ${File_Package} ; do
	mkdir ${Build_Root}/Pkg_Temp
	cd ${Build_Root}/Pkg_Temp
	explodepkg ../${Each} .
	rm install/slack-desc
	cat install/doinst.sh >> ${Package_Root}/install/doinst.sh
	rm -rf install/
	( cd usr/src ; cp -aR * ${Package_Root}/usr/src/${Package_Duo}/ )
	rm -rf usr/src
	cp -aR * ${Package_Root}/
	cd ${Build_Root}
	rm -rf Pkg_Temp
done

cd ${Package_Root}/usr/src/*
mkdir individual-build-srcipts
mv * individual-build-srcipts
tar jcf individual-build-srcipts.tar.bz2 individual-build-srcipts/
rm -rf individual-build-srcipts


# Complete the final packaging routines:
#_______________________________________________________________________
mkdir ${Package_Root}/install
cat <<EOF1 > ${Package_Root}/install/slack-desc
${Package_Name}${Desc_Line_00}
${Package_Name}${Desc_Line_01}
${Package_Name}${Desc_Line_02}
${Package_Name}${Desc_Line_03}
${Package_Name}${Desc_Line_04}
${Package_Name}${Desc_Line_05}
${Package_Name}${Desc_Line_06}
${Package_Name}${Desc_Line_07}
${Package_Name}${Desc_Line_08}
${Package_Name}${Desc_Line_09}
${Package_Name}${Desc_Line_10}
EOF1

cd ${Build_Root}
cp ${File_Misc} ${File_Script} ${Package_Root}/usr/src/${Package_Duo}

( cd ${Package_Root} ;
	requiredbuilder -z ${Package_Root} > ${Build_Root}/${Package_Title}.dep
)

( cd ${Package_Root}
	makepkg -l y -c n ${Build_Root}/${Package_Title}.tgz
)
cd ${Build_Root}
md5sum ${Package_Title}.tgz > ${Package_Title}.md5
rm -rf ${Package_Root}

mkdir -p ${Package_Root}.src
cp ${File_Misc} ${File_Script} ${Package_Root}.src
tar -jcf ${Package_Title}.src.tbz ${Package_Title}.src
rm -rf ${Package_Title}.src 
md5sum ${Package_Title}.src.tbz > ${Package_Title}.src.md5


# Changelog of script edits:
#_______________________________________________________________________


# ~ Thu Apr 16th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Build:		62.6
# ~ Changes:	Updated xcb-util-0.3.4

# ~ Wed Mar 11th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Build:		62.5
# ~ Changes:	Rebuilt against gcc-4.3.3

# ~ Wed Mar 11th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Build:		62.4
# ~ Changes:	More libxcb-xlib fixes

# ~ Mon Mar 9th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Build:		62.3
# ~ Changes:	More libxcb-xlib fixes

# ~ Mon Mar 9th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Build:		62.2
# ~ Changes:	Added lame libxcb-xlib.la file

# ~ Fri Feb 20th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Build:		62.1
# ~ Changes:	n/a (Original script creation)
