#!/bin/bash

#     Copyright (C) 2009 Michael Verret <michael.verret@gmail.com>
#
#            This script is released under the terms of the:
#                      GNU GENERAL PUBLIC LICENSE
#                        Version 3, 29 June 2007
#                http://www.gnu.org/licenses/gpl-3.0.txt
#
# This is a Bash shell script written to automate the process of
# generating software packages suitable for use with Zenwalk Linux.
#
# Zenwalk Linux is a GNU/Linux operating system.
#
#              For more information on Zenwalk Linux visit:
#                        http://www.zenwalk.org/
#
# Bash is a free software Unix shell written for the GNU Project.
#
#                   For more information on Bash visit:
#           http://tiswww.case.edu/php/chet/bash/bashtop.html


# Package information:
#_______________________________________________________________________
# Name:			xcb-lib
# Summary:		The X C Binding (XCB) library
# Group:		X Window System Environment/XCB Protocol Headers


# Source information:
#_______________________________________________________________________
# License:		Copyright (C) 2001-2006 Bart Massey, Jamey Sharp, and
#               Josh Triplett. All Rights Reserved.
# Home URL:		http://xcb.freedesktop.org/
# Bug Reports:	xcb@lists.freedesktop.org


# Build information:
#_______________________________________________________________________
# BuildRequires: doxygen
# BuildRequires: gperf


# Runtime information:
#_______________________________________________________________________
# Requires:


# Environment variables:
#_______________________________________________________________________
Build_Root=$(pwd)
Flag_Arch="i686"


# Source variables:
#_______________________________________________________________________
Source_Name="libxcb"
Source_Version="1.2"
Source_Duo="${Source_Name}-${Source_Version}"
Source_Format="tar.bz2"
Source_Title="${Source_Duo}.${Source_Format}"
Source_URL="http://xcb.freedesktop.org/dist/${Source_Name}"


# Package variables:
#_______________________________________________________________________
Package_Name="xcb-lib"
Package_Version="${Source_Version}"
Package_Duo="${Package_Name}-${Package_Version}"
Package_Arch="${Flag_Arch}"
Package_Release="62"
Package_Build="4"
Package_Title="${Package_Duo}-${Package_Arch}-${Package_Release}.${Package_Build}"
Package_Root="${Build_Root}/${Package_Title}"


# Package documentation variables:
#_______________________________________________________________________
Package_Doc_Name="xcb-lib-docs"
Package_Doc_Version="${Source_Version}"
Package_Doc_Duo="${Package_Doc_Name}-${Package_Doc_Version}"
Package_Doc_Arch="noarch"
Package_Doc_Release="${Package_Release}"
Package_Doc_Build="${Package_Build}"
Package_Doc_Title="${Package_Doc_Duo}-${Package_Doc_Arch}-${Package_Doc_Release}.${Package_Doc_Build}"
Package_Doc_Root="${Build_Root}/${Package_Doc_Title}"


# Documentation variables:
#_______________________________________________________________________
Special_Docs=" "
Standard_Docs="AUTHORS BUGS COPYING ChangeLog INSTALL LICENSE NEWS README"


# Miscellaneous file variables:
#_______________________________________________________________________
File_Image=" \
	xcb-documentation.png"
File_Misc=" \
	pthread-stubs.pc.in.gz"
File_Patch=" \
	libxcb-1.1-no-pthread-stubs.patch.gz"
File_Script=" \
	build-${Package_Name}.sh"
Custom_Files="${File_Image} ${File_Misc} ${File_Patch} ${File_Script}"


# Environment preparation:
#_______________________________________________________________________
# Check for necessary files:
# Note: Valid variables are: ${Source_Title} ${File_Image} ${File_Misc}
# ${File_Patch} and ${File_Script}
Required_Files="${Source_Title} ${File_Image} ${File_Misc} ${File_Patch} ${File_Script}"
for Each_File in ${Required_Files} ; do
	echo -n "${Each_File} :"
	if [ -e ${Each_File} ]; then
		echo " OK"
	else
		echo " MISSING !"
		exit 1
	fi
done

# Remove possible packaging cruft:
Possible_Cruft=" \
	${Source_Duo} \
	${Package_Title} \
	${Package_Title}.{dep,md5,src.md5,src.tbz,tgz,} \
	${Package_Doc_Title} \
	${Package_Doc_Title}.{dep,md5,src.md5,src.tbz,tgz,}"
for Each in ${Possible_Cruft} ; do
	if [ -e ${Each} ]; then rm -rf ${Each}
	fi
done


# Package preparation:
#_______________________________________________________________________
# Create package root:
mkdir ${Package_Root}

# Add a package description file:
mkdir ${Package_Root}/install
cat <<EOF0 > ${Package_Root}/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

       |-----handy-ruler------------------------------------------------------|
${Package_Name}: ${Package_Name} (The X C Binding (XCB) library)
${Package_Name}:
${Package_Name}: The X protocol C-language Binding (XCB) is a replacement for Xlib
${Package_Name}: featuring a small footprint, latency hiding, direct access to the
${Package_Name}: protocol, improved threading support, and extensibility.
${Package_Name}:
${Package_Name}:
${Package_Name}:
${Package_Name}:
${Package_Name}:
${Package_Name}:
EOF0

# Add a package description file for the docs:
mkdir -p ${Package_Doc_Root}/install
cat <<EOF1 > ${Package_Doc_Root}/install/slack-desc 
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

            |-----handy-ruler------------------------------------------------------|
${Package_Doc_Name}: ${Package_Doc_Name} (Additional documentation for libxcb)
${Package_Doc_Name}:
${Package_Doc_Name}: The X protocol C-language Binding (XCB) is a replacement for Xlib
${Package_Doc_Name}: featuring a small footprint, latency hiding, direct access to the
${Package_Doc_Name}: protocol, improved threading support, and extensibility.
${Package_Doc_Name}:
${Package_Doc_Name}:
${Package_Doc_Name}:
${Package_Doc_Name}:
${Package_Doc_Name}:
${Package_Doc_Name}:
EOF1

# Add a desktop file for the additional documentation:
mkdir -p ${Package_Doc_Root}/usr/share/applications
cat <<EOF2 >  ${Package_Doc_Root}/usr/share/applications/libxcb-documentation.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=firefox file:///usr/doc/${Package_Duo}/manual/index.html
Icon=xcb-documentation
Type=Application
Categories=Application;Development;
Name=XCB Documentation
GenericName=Documentation for developing with XCB
EOF2
mkdir -p ${Package_Doc_Root}/usr/share/icons/hicolor/48x48/apps
cp ${Build_Root}/xcb-documentation.png \
	${Package_Doc_Root}/usr/share/icons/hicolor/48x48/apps/
	
# Install source files other than those available upstream:
mkdir -p ${Package_Root}/usr/src/${Package_Duo}
for Each_Custom in ${Custom_Files} ; do
	if [ -e ${Each_File} ]; then
		cp ${Each_Custom} \
			${Package_Root}/usr/src/${Package_Duo}/
	fi
done
mkdir -p ${Package_Doc_Root}/usr/src/${Package_Doc_Duo}
for Each_Custom in ${Custom_Files} ; do
	if [ -e ${Each_File} ]; then
		cp ${Each_Custom} \
			${Package_Doc_Root}/usr/src/${Package_Doc_Duo}/
	fi
done

# Source code preparation:
#_______________________________________________________________________
# Extract the source code:
for Archive in ${Source_Title} ; do
	File_Type=$(file -biz "${Archive}")
	unset Command
	case "${File_Type}" in
		*application/x-tar*)
			Command="tar -xf" ;;
		*application/x-zip*)
			Command="unzip" ;;
		*application/x-gzip*)
			Command="gunzip -d -f" ;;
		*application/x-bzip*)
			Command="bunzip2 -f" ;;
	esac
	if [ "$Command" != "" ]; then
		echo "${Command} ${Archive}"
		${Command} ${Archive} || exit 1
	fi
done

# Enter source code directory:
cd ${Source_Duo}

# Ensure proper permissions and ownership of the source code files:
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# libxcb-1.1.93-namespace-pollution.patch: Hide Xalloc and friends from
# the dynamic linker:
zcat ${Build_Root}/libxcb-1.1-no-pthread-stubs.patch.gz | patch -p1 -b --suffix=.hidden || exit 1

# Update configuration files to end needless warnings:
autoreconf -v --install
		
# Configure the souce code to adapt to the desired operating system:
export CFLAGS="-O2 -march=${Flag_Arch} -pipe" 
export CXXFLAGS="${CFLAGS}" 
export PKG_CONFIG_PATH=/usr/lib/pkgconfig
./configure \
--prefix=/usr \
--bindir=/usr/bin \
--datadir=/usr/share \
--sysconfdir=/etc \
--localstatedir=/var \
--libdir=/usr/lib \
--includedir=/usr/include \
--mandir=/usr/man \
--docdir=/usr/doc/${Package_Duo}/
--htmldir=/usr/doc/${Package_Duo}/html \
--disable-static \
--disable-xprint \
--enable-build-docs \
--with-doxygen \
--silent
# Update doxygen files:
( cd doc ; doxygen -u *.doxygen )


# Source code transformation and installation:
#_______________________________________________________________________
# Transform the source code into the target computer language:
make --silent || exit 1

# Make libxcb-xlib.so.0 to enable some software to work until they are
# updated to build and run without libxcb-xlib.so.0:
touch libxcb-xlib.c
gcc -shared -Wl,-soname,libxcb-xlib.so.0 -o libxcb-xlib.so.0 libxcb-xlib.c

# Run tests on the target computer language if available:
make check || exit 1

# Install the target computer language into the package directory:
make install --silent  DESTDIR=${Package_Root} || exit 1

# Make lame libxcb-xlib.la file (lame as in DIE DIE DIE *.la files!!!)
cat <<EOF2 >  ${Package_Root}/usr/lib/libxcb-xlib.la || exit 1
# libxcb-xinerama.la - a libtool library file
# Generated by ltmain.sh - GNU libtool 1.5.26 Debian 1.5.26-4 (1.1220.2.493 2008/02/01 16:58:18)
#
# Please DO NOT delete this file!
# It is necessary for linking the library.

# The name that we can dlopen(3).
dlname='libxcb-xlib.so.0'

# Names of this library.
library_names='libxcb-xlib.so.0 libxcb-xlib.so'

# The name of the static archive.
old_library=''

# Libraries that this one depends upon.
dependency_libs=''

# Version information for libxcb-xlib.
current=0
age=0
revision=0

# Is this an already installed library?
installed=yes

# Should we warn about portability when linking against -modules?
shouldnotlink=no

# Files to dlopen/dlpreopen
dlopen=''
dlpreopen=''

# Directory that this library needs to be installed in:
libdir='/usr/lib'

EOF2

# Install pthread-stubs file:
zcat ${Build_Root}/pthread-stubs.pc.in.gz > ${Build_Root}/pthread-stubs.pc.in

# Fix up libxcb-xlib.so.0 a little:
sed 's,@libdir@,%{_libdir},;s,@prefix@,%{_prefix},;s,@exec_prefix@,%{_exec_prefix},' ${Build_Root}/pthread-stubs.pc.in > \
${Package_Root}/usr/lib/pkgconfig/pthread-stubs.pc || exit 1
rm ${Build_Root}/pthread-stubs.pc.in || exit 1
install libxcb-xlib.so.0 ${Package_Root}/usr/lib/ || exit 1
		
# Don't forget about libxcb-xlib.so!!!
( cd ${Package_Root}/usr/lib/ ; ln -s libxcb-xlib.so.0 libxcb-xlib.so )

# Install the documentation into the package directory:
mkdir -p ${Package_Root}/usr/doc/${Package_Duo}/
for Each_Doc in {${Special_Docs},${Standard_Docs}} ; do
	if [ -e ${Each_Doc} ] ; then
		cp ${Each_Doc} ${Package_Root}/usr/doc/${Package_Duo}/
	fi
done

# Install additional the documentation into the docs package directory:
cd ${Package_Root}/usr/doc/${Package_Duo}/ || exit 1
mkdir -p ${Package_Doc_Root}/usr/doc/${Package_Duo}/ || exit 1
cp -aR manual ${Package_Doc_Root}/usr/doc/${Package_Duo}/ || exit 1
cp -aR tutorial ${Package_Doc_Root}/usr/doc/${Package_Duo}/ || exit 1
rm -rf manual tutorial || exit 1
		
# Delete empty documentation files from the package directory:
( cd ${Package_Root}/usr/doc/${Package_Duo}/
	find . -name "*" -size 0c -exec rm {} \;
)

# Delete the source directory now that it is no longer necessary:
cd ${Build_Root}
rm -rf ${Source_Duo}


# Complete the final packaging routines:
#_______________________________________________________________________
# Strip binary files:
( cd ${Package_Root}
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress the man page files.
if [ -d ${Package_Root}/usr/man ]; then
	( cd ${Package_Root}/usr/man
		gzip -9 */*
	)
fi

# Create the package manager dependency listing:
( cd ${Package_Root}
	requiredbuilder -z ${Package_Root} > ${Build_Root}/${Package_Title}.dep
)

# Create the documentation package manager dependency listing:
touch ${Build_Root}/${Package_Doc_Title}.dep

# Create the final package format, then calculate and store it's md5 checksum:
( cd ${Package_Root}
	makepkg -l y -c n ${Build_Root}/${Package_Title}.tgz
)
cd ${Build_Root}
md5sum ${Package_Title}.tgz > ${Package_Title}.md5
rm -rf ${Package_Root}

# Create the final documentation package format, then calculate and store
# it's md5 checksum:
( cd ${Package_Doc_Root}
	makepkg -l y -c n ${Build_Root}/${Package_Doc_Title}.tgz
)
cd ${Build_Root}
md5sum ${Package_Doc_Title}.tgz > ${Package_Doc_Title}.md5
rm -rf ${Package_Doc_Root}

# Create a source package then calculate and store it's md5 checksum:
mkdir -p ${Package_Root}.src
cp ${Source_Title} ${Package_Root}.src
for Each_Set in ${Custom_Files} ; do
	if [ -e ${Each_Set} ] ; then
		cp ${Each_Set} ${Package_Root}.src
	fi
done
tar -jcf ${Package_Title}.src.tbz ${Package_Title}.src
rm -rf ${Package_Title}.src 
md5sum ${Package_Title}.src.tbz > ${Package_Title}.src.md5

# Create a documentation source package then calculate and store it's md5
# checksum:
mkdir -p ${Package_Doc_Title}.src
cp ${Source_Title} ${Package_Doc_Title}.src
for Each_Set in ${Custom_Files} ; do
	if [ -e ${Each_Set} ] ; then
		cp ${Each_Set} ${Package_Doc_Title}.src
	fi
done
tar -jcf ${Package_Doc_Title}.src.tbz ${Package_Doc_Title}.src
rm -rf ${Package_Doc_Title}.src 
md5sum ${Package_Doc_Title}.src.tbz > ${Package_Doc_Title}.src.md5


# Changelog of script edits:
#_______________________________________________________________________


# ~ Wed Mar 11th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Build:		62.4
# ~ Changes:	More libxcb-xlib fixes

# ~ Mon Mar 9th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Build:		62.3
# ~ Changes:	More libxcb-xlib fixes

# ~ Mon Mar 9th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Build:		62.2
# ~ Changes:	Added lame libxcb-xlib.la file

# ~ Fri Feb 20th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Build:		62.1
# ~ Changes:	n/a (Original script creation)
