#!/bin/bash
# Filename: build-automake.sh
# Automates the packaging process of the software "xpyb" for
# use with Zenwalk Linux.  
# Copyright (C) 2009 Michael Verret michael.verret@gmail.com
# Software source: http://ftp.gnu.org/gnu/xpyb/
# Software dependencies: "m4"

WorkArea=$(pwd)
SoftwareName='xpyb'
SoftwareVersion='1.1'
CompressionAlgorithm='tar.gz'
BuildArch='i686'
PackageBuild='62.1'
Documentation=" \
	INSTALL \
	NEWS \
	README"

# Files from previous builds are considered cruft.
Cruft=" \
	$SoftwareName-$SoftwareVersion \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild.* \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild-src \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild-src.*"
for Each in ${Cruft} ; do
	if [ -e $Each ] ; then
		rm -rf $Each
	fi
done

tar -xvzf $SoftwareName-$SoftwareVersion.$CompressionAlgorithm

cd $SoftwareName-$SoftwareVersion
chown -R root:root .
find . \
	\( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
	-exec chmod 755 {} \; -o \
	\( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
	-exec chmod 644 {} \;

export CFLAGS="-O2 -march=$BuildArch -pipe"
./configure \
--prefix=/usr

make || exit 1
make install DESTDIR=$WorkArea/$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild || exit 1

cd $WorkArea/$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
gzip -9 usr/info/*

mkdir -p $WorkArea/$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild/install
cat <<EOF0 > $WorkArea/$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild/install/slack-desc 
    |-----handy-ruler------------------------------------------------------|
xpyb: xpyb (Python binding to the X Window System protocol)
xpyb:
xpyb: xpyb provides a Python binding to the X Window System protocol
xpyb: via libxcb.
xpyb:
xpyb:
xpyb:
xpyb:
xpyb:
xpyb:
xpyb:
EOF0

cd $WorkArea/$SoftwareName-$SoftwareVersion
mkdir -p $WorkArea/$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild/usr/doc/$SoftwareName-$SoftwareVersion
cp $Documentation \
	$WorkArea/$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild/usr/doc/$SoftwareName-$SoftwareVersion  1>/dev/null 2>&1
cd $WorkArea/$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild/usr/doc/$SoftwareName-$SoftwareVersion ; \
	find . -name "*" -size 0c -exec rm {} \;

cd $WorkArea
mkdir -p $WorkArea/$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild/usr/src/$SoftwareName-$SoftwareVersion
cp build-$SoftwareName.sh $WorkArea/$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild/usr/src/$SoftwareName-$SoftwareVersion

cd $WorkArea/$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild
makepkg -l y -c n ../$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild.tgz

cd $WorkArea
depfinder -f $SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild.tgz > \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild.dep
md5sum $SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild.tgz > \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild.md5

mkdir $SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild-src
cp build-$SoftwareName.sh \
	$SoftwareName-$SoftwareVersion.$CompressionAlgorithm \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild-src
tar -jcf $SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild-src.tbz \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild-src
md5sum $SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild-src.tbz > \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild-src.md5
rm -rf $SoftwareName-$SoftwareVersion \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild \
	$SoftwareName-$SoftwareVersion-$BuildArch-$PackageBuild-src

# CHANGELOG:
# ~ Thu Apr 16th 2009	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Software: xpyb-1.1
# ~ Build: 62.1
